@@ -20,7 +20,7 @@ import re
 import io
 import boto3
 
-hm = str(Path.home())
+HM = str(Path.home())
 
 # A simple date format for checking dates.
 DT_FORMAT = "(\d{4}[-/]\d{1,2}[-/]\d{1,2})|(\d{1,2}[-/]\d{1,2}[-/]\d{4})"
@@ -29,11 +29,11 @@ from datascientist.special import s3session
 
 ### Look for the appropriate environment variables.
 
-username = os.environ.get("REDSHIFT_USER_NAME")
-dbname = os.environ.get("REDSHIFT_DBNAME")
-port = os.environ.get("REDSHIFT_PORT")
-passwd = os.environ.get("REDSHIFT_PASSWORD")
-host = os.environ.get("REDSHIFT_HOST")
+username = os.environ.get("RS_USER")
+dbname = os.environ.get("RS_DBNM")
+port = os.environ.get("RS_PORT")
+passwd = os.environ.get("RS_PASS")
+host = os.environ.get("RS_HOST")
 
 ### If they're not present, get them from a creds file
 
