@@ -29,8 +29,8 @@ def configure_access(bucket, cluster, region):
 	else:
 		logger.info("Attempting to set AWS credentials")
 		try:
-			subprocess.run(["aws", "configure", "set", "aws_access_key_id" "$AWS_S3_SPECIAL_KEY"])
-			subprocess.run(["aws", "configure", "set", "aws_secret_access_key" "$AWS_S3_SPECIAL_SECRET"])
+			subprocess.run(["aws", "configure", "set", "aws_access_key_id" "$AWS_ACCESS_KEY_ID"])
+			subprocess.run(["aws", "configure", "set", "aws_secret_access_key" "$AWS_SECRET_ACCESS_KEY"])
 		except Exception as e:
 			logging.error("Exception {} occurred".format(e), exc_info=True)
 	try:
@@ -65,7 +65,9 @@ class Trainer:
 		name,
 		bucket,
 		image_tag,
-		cluster_name='cloudframe-jupyterhub',
+		mem_guarantee='65G',
+		mem_limit='124G',
+		cluster_name='cdse-demo',
 		region='us-east-2',
 		repo="cloudframedotio/trainers"
 		):
@@ -80,6 +82,8 @@ class Trainer:
 		self.bucket_obj = boto3.resource('s3').Bucket(bucket)
 		self.repo = repo
 		self.model_location = None
+		self.mem_guarantee = mem_guarantee
+		self.mem_limit = mem_limit
 
 	def store_params(self, params):
 		"""
@@ -107,7 +111,7 @@ class Trainer:
 		if mod_location is None:
 			logger.info("no model location yet for this job")
 			return
-		if s3_isfile(mod_location, self.bucket):
+		if s3_isfile(mod_location, self.bucket_obj):
 			bucket_obj.download_file(Key=mod_location, Filename=filename)
 			model = pickle.load(open(filename, "rb"))
 		else:
@@ -132,6 +136,8 @@ class Trainer:
 		params = self.store_params(hyperparameters)
 		name = self.name
 		bucket = self.bucket
+		mem_guarantee = self.mem_guarantee
+		mem_limit = self.mem_limit
 
 		commands = [
 			"python",
@@ -147,7 +153,7 @@ class Trainer:
 			"-n={}".format(n_jobs),
 			"-m={}".format(name)
 		]
-		this_job = JOB.format(name, image, commands)
+		this_job = JOB.format(name, image, mem_guarantee, mem_limit, commands)
 		js_name = "/tmp/jobspec_{}.yaml".format(name)
 		with open(js_name, "w") as file:
 			file.write(this_job)
