@@ -9,10 +9,10 @@ import json
 import io
 from pathlib import Path
 
-hm = str(Path.home())
+HM = str(Path.home())
 
-access = os.environ.get("AWS_S3_SPECIAL_KEY")
-secret = os.environ.get("AWS_S3_SPECIAL_SECRET")
+access = os.environ.get("AWS_ACCESS_KEY_ID")
+secret = os.environ.get("AWS_SECRET_ACCESS_KEY")
 
 def check_bucket(bucket):
     """
@@ -42,7 +42,7 @@ def get_resource():
     ret = sess.resource('s3')
     return ret
 
-def read_creds():
+def read_creds(profile='default'):
     """
     @doc: look for locally stored AWS credentials
     @args: None
@@ -50,16 +50,20 @@ def read_creds():
     @note: if none are found then return None
     """
     ret = None
+    get_cred = False
     if os.path.isfile("{}/.aws/credentials".format(hm)):
         access = None
         secret = None
         with open("{}/.aws/credentials".format(hm)) as file:
             lines = file.readlines()
         for line in lines:
-            if line[:10] == 'aws_access':
-                access = line[line.find("=") + 2:-1]
-            elif line[:10] == 'aws_secret':
-                secret = line[line.find("=") + 2:-1]
+            if profile in line:
+                get_cred = True
+            if "key_id" in line and get_cred:
+                access = line[line.find("=") + 2:].rstrip()
+            elif "access_key" in line and get_cred:
+                secret = line[line.find("=") + 2:].rstrip()
+                get_cred = False
         ret = access, secret
     return ret
 
